@@ -17,7 +17,7 @@ from metadata_service.api.healthcheck import healthcheck
 from metadata_service.api.popular_tables import PopularTablesAPI
 from metadata_service.api.system import Neo4jDetailAPI
 from metadata_service.api.table \
-    import TableDetailAPI, TableOwnerAPI, TableTagAPI, TableDescriptionAPI
+    import TableDetailAPI, TableOwnerAPI, TableTagAPI, TableDescriptionAPI, TableDashboardAPI
 from metadata_service.api.tag import TagAPI
 from metadata_service.api.user import (UserDetailAPI, UserFollowAPI,
                                        UserFollowsAPI, UserOwnsAPI,
@@ -91,6 +91,8 @@ def create_app(*, config_module_class: str) -> Flask:
                      '/table/<path:id>/tag/<tag>')
     api.add_resource(TableOwnerAPI,
                      '/table/<path:table_uri>/owner/<owner>')
+    api.add_resource(TableDashboardAPI,
+                     '/table/<path:id>/dashboard/')
     api.add_resource(ColumnDescriptionAPI,
                      '/table/<path:table_uri>/column/<column_name>/description')
     api.add_resource(Neo4jDetailAPI,
