@@ -55,11 +55,19 @@ class AtlasProxy(BaseProxy):
                  host: str,
                  port: int,
                  user: str = 'admin',
-                 password: str = '') -> None:
+                 password: str = '',
+                 encrypted: bool = False,
+                 validate_ssl: bool = False) -> None:
         """
         Initiate the Apache Atlas client with the provided credentials
         """
-        self._driver = Atlas(host=host, port=port, username=user, password=password)
+        protocol = 'https' if encrypted else 'http'
+        self._driver = Atlas(host=host,
+                             port=port,
+                             username=user,
+                             password=password,
+                             protocol=protocol,
+                             validate_ssl=validate_ssl)
 
     def _get_ids_from_basic_search(self, *, params: Dict) -> List[str]:
         """
